@echo off
rem --------------------------------------------------------------------------
rem subroutine compare_size
rem Usage: 
rem   CALL compare_size "installed-file" "new-file"
rem   where installed-file and new-file are full paths to the files to compare
rem
rem Result:
rem   sets IS_SIZE_BIGGER to "true" if new-file is bigger than installed-file
rem
rem Sample Usage:
rem   CALL compare_size.bat "existingUserFile.chm" "myNewFile.chm"
rem
rem   if %IS_SIZE_BIGGER% EQU true (
rem     echo Installing bigger file...
rem     copy /Y %myNewFile.chm% "%COMMON%\myNewFile.chm"
rem   )
rem --------------------------------------------------------------------------


rem %1 is the existing or installed file.
rem %2 is the new file to compare.

set IS_SIZE_BIGGER=false

rem If there is no installed file, then the "new-file" is obviously bigger.
if exist "%~1" (
	call :compare_size "%~1" "%~2"
) else (
	echo "%~1" does not exist.
	set IS_SIZE_BIGGER=true
)
goto :end


rem --------------------------------------------------------------------------
rem compare_size subroutine
rem --------------------------------------------------------------------------
:compare_size
echo compare_size...

rem Pretty formatting for output (numbers are right aligned).
setlocal
set s1=          %~z1
set s2=          %~z2
echo installed: %s1:~-10%  %~1
echo update:    %s2:~-10%  %~2
endlocal

if %~z1 LSS %~z2 (
	set IS_SIZE_BIGGER=true
)

goto:EOF
rem endo compare_size

:end
