@echo off
rem --------------------------------------------------------------------------
rem subroutine compare_versions
rem Usage: 
rem   CALL compare_versions "installed-file" "new-file"
rem   where installed-file and new-file are full paths to EXE or DLL files
rem   with file version information.
rem
rem Result:
rem   sets HAVE_NEW_VERSION to "true" if new-file is newer than installed-file
rem
rem Sample Usage:
rem   CALL compare_versions.bat "existingUserFile.dll" "myNewFile.dll"
rem
rem   if %HAVE_NEW_VERSION% EQU true (
rem     echo Installing new file...
rem     copy /Y %myNewFile.dll% "%COMMON%\myNewFile.dll"
rem   )
rem --------------------------------------------------------------------------

rem %1 is the existing or installed file.
rem %2 is the new file to compare.

set HAVE_NEW_VERSION=false

echo.

rem If there is no installed file, then the "new-file" is obviously newer.
rem Note, when this batch file is called from another, we don't need quotes
rem around %1 and %2 in the call below, otherwise we get ""%1"" in the 
rem subroutine.
if exist "%~1" (
	call :compare_versions "%~1" "%~2"
) else (
	echo %~nx1 has not been installed, installing new version...
	set HAVE_NEW_VERSION=true
)
goto :end


rem --------------------------------------------------------------------------
rem compare_versions subroutine
rem --------------------------------------------------------------------------
:compare_versions
echo compare_versions...
rem Get the installed version "y".
FOR /F "tokens=5-8 delims=.	 " %%A IN ('Filever.EXE "%~1" /B /D') DO (
	set y1=%%A
	set y2=%%B
	set y3=%%C
	set y4=%%D
)
rem Get the PrnInst version "z".
FOR /F "tokens=5-8 delims=.	 " %%i IN ('Filever.EXE "%~2" /B /D') DO (
	set z1=%%i
	set z2=%%j
	set z3=%%k
	set z4=%%l
)

echo  installed: %y1%.%y2%.%y3%.%y4%	%1
echo  update:    %z1%.%z2%.%z3%.%z4%	%2

set HAVE_NEW_VERSION=false
if %y1% LSS %z1% (
	set HAVE_NEW_VERSION=true
	goto:EOF
)
if %y1% EQU %z1% if %y2% LSS %z2% (
	set HAVE_NEW_VERSION=true
	goto:EOF
)
if %y1% EQU %z1% if %y2% EQU %z2% if %y3% LSS %z3% (
	set HAVE_NEW_VERSION=true
	goto:EOF
)
if %y1% EQU %z1% if %y2% EQU %z2% if %y3% EQU %z3% if %y4% LSS %z4% (
	set HAVE_NEW_VERSION=true
	goto:EOF
)
if %y1% EQU %z1% if %y2% EQU %z2% if %y3% EQU %z3% if %y4% EQU %z4% (
	echo versions are equal
	set HAVE_NEW_VERSION=equal
	goto:EOF
)
echo  no change, installed is newer
goto :EOF
rem end compare_versions


:end
